import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { AutoScalingClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../AutoScalingClient";
import { DescribeMetricCollectionTypesAnswer } from "../models/models_0";
/**
 * @public
 */
export { __MetadataBearer, $Command };
/**
 * @public
 *
 * The input for {@link DescribeMetricCollectionTypesCommand}.
 */
export interface DescribeMetricCollectionTypesCommandInput {
}
/**
 * @public
 *
 * The output of {@link DescribeMetricCollectionTypesCommand}.
 */
export interface DescribeMetricCollectionTypesCommandOutput extends DescribeMetricCollectionTypesAnswer, __MetadataBearer {
}
declare const DescribeMetricCollectionTypesCommand_base: {
    new (input: DescribeMetricCollectionTypesCommandInput): import("@smithy/smithy-client").CommandImpl<DescribeMetricCollectionTypesCommandInput, DescribeMetricCollectionTypesCommandOutput, AutoScalingClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (...[input]: [] | [DescribeMetricCollectionTypesCommandInput]): import("@smithy/smithy-client").CommandImpl<DescribeMetricCollectionTypesCommandInput, DescribeMetricCollectionTypesCommandOutput, AutoScalingClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Describes the available CloudWatch metrics for Amazon EC2 Auto Scaling.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { AutoScalingClient, DescribeMetricCollectionTypesCommand } from "@aws-sdk/client-auto-scaling"; // ES Modules import
 * // const { AutoScalingClient, DescribeMetricCollectionTypesCommand } = require("@aws-sdk/client-auto-scaling"); // CommonJS import
 * const client = new AutoScalingClient(config);
 * const input = {};
 * const command = new DescribeMetricCollectionTypesCommand(input);
 * const response = await client.send(command);
 * // { // DescribeMetricCollectionTypesAnswer
 * //   Metrics: [ // MetricCollectionTypes
 * //     { // MetricCollectionType
 * //       Metric: "STRING_VALUE",
 * //     },
 * //   ],
 * //   Granularities: [ // MetricGranularityTypes
 * //     { // MetricGranularityType
 * //       Granularity: "STRING_VALUE",
 * //     },
 * //   ],
 * // };
 *
 * ```
 *
 * @param DescribeMetricCollectionTypesCommandInput - {@link DescribeMetricCollectionTypesCommandInput}
 * @returns {@link DescribeMetricCollectionTypesCommandOutput}
 * @see {@link DescribeMetricCollectionTypesCommandInput} for command's `input` shape.
 * @see {@link DescribeMetricCollectionTypesCommandOutput} for command's `response` shape.
 * @see {@link AutoScalingClientResolvedConfig | config} for AutoScalingClient's `config` shape.
 *
 * @throws {@link ResourceContentionFault} (server fault)
 *  <p>You already have a pending update to an Amazon EC2 Auto Scaling resource (for example, an Auto Scaling group,
 *             instance, or load balancer).</p>
 *
 * @throws {@link AutoScalingServiceException}
 * <p>Base exception class for all service exceptions from AutoScaling service.</p>
 *
 * @public
 * @example To describe the Auto Scaling metric collection types
 * ```javascript
 * // This example describes the available metric collection types.
 * const input = {};
 * const command = new DescribeMetricCollectionTypesCommand(input);
 * const response = await client.send(command);
 * /* response ==
 * {
 *   "Granularities": [
 *     {
 *       "Granularity": "1Minute"
 *     }
 *   ],
 *   "Metrics": [
 *     {
 *       "Metric": "GroupMinSize"
 *     },
 *     {
 *       "Metric": "GroupMaxSize"
 *     },
 *     {
 *       "Metric": "GroupDesiredCapacity"
 *     },
 *     {
 *       "Metric": "GroupInServiceInstances"
 *     },
 *     {
 *       "Metric": "GroupPendingInstances"
 *     },
 *     {
 *       "Metric": "GroupTerminatingInstances"
 *     },
 *     {
 *       "Metric": "GroupStandbyInstances"
 *     },
 *     {
 *       "Metric": "GroupTotalInstances"
 *     }
 *   ]
 * }
 * *\/
 * // example id: autoscaling-describe-metric-collection-types-1
 * ```
 *
 */
export declare class DescribeMetricCollectionTypesCommand extends DescribeMetricCollectionTypesCommand_base {
}
