import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { AutoScalingClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../AutoScalingClient";
import { DescribeTerminationPolicyTypesAnswer } from "../models/models_0";
/**
 * @public
 */
export { __MetadataBearer, $Command };
/**
 * @public
 *
 * The input for {@link DescribeTerminationPolicyTypesCommand}.
 */
export interface DescribeTerminationPolicyTypesCommandInput {
}
/**
 * @public
 *
 * The output of {@link DescribeTerminationPolicyTypesCommand}.
 */
export interface DescribeTerminationPolicyTypesCommandOutput extends DescribeTerminationPolicyTypesAnswer, __MetadataBearer {
}
declare const DescribeTerminationPolicyTypesCommand_base: {
    new (input: DescribeTerminationPolicyTypesCommandInput): import("@smithy/smithy-client").CommandImpl<DescribeTerminationPolicyTypesCommandInput, DescribeTerminationPolicyTypesCommandOutput, AutoScalingClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (...[input]: [] | [DescribeTerminationPolicyTypesCommandInput]): import("@smithy/smithy-client").CommandImpl<DescribeTerminationPolicyTypesCommandInput, DescribeTerminationPolicyTypesCommandOutput, AutoScalingClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Describes the termination policies supported by Amazon EC2 Auto Scaling.</p>
 *          <p>For more information, see <a href="https://docs.aws.amazon.com/autoscaling/ec2/userguide/ec2-auto-scaling-termination-policies.html">Work with
 *                 Amazon EC2 Auto Scaling termination policies</a> in the
 *             <i>Amazon EC2 Auto Scaling User Guide</i>.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { AutoScalingClient, DescribeTerminationPolicyTypesCommand } from "@aws-sdk/client-auto-scaling"; // ES Modules import
 * // const { AutoScalingClient, DescribeTerminationPolicyTypesCommand } = require("@aws-sdk/client-auto-scaling"); // CommonJS import
 * const client = new AutoScalingClient(config);
 * const input = {};
 * const command = new DescribeTerminationPolicyTypesCommand(input);
 * const response = await client.send(command);
 * // { // DescribeTerminationPolicyTypesAnswer
 * //   TerminationPolicyTypes: [ // TerminationPolicies
 * //     "STRING_VALUE",
 * //   ],
 * // };
 *
 * ```
 *
 * @param DescribeTerminationPolicyTypesCommandInput - {@link DescribeTerminationPolicyTypesCommandInput}
 * @returns {@link DescribeTerminationPolicyTypesCommandOutput}
 * @see {@link DescribeTerminationPolicyTypesCommandInput} for command's `input` shape.
 * @see {@link DescribeTerminationPolicyTypesCommandOutput} for command's `response` shape.
 * @see {@link AutoScalingClientResolvedConfig | config} for AutoScalingClient's `config` shape.
 *
 * @throws {@link ResourceContentionFault} (server fault)
 *  <p>You already have a pending update to an Amazon EC2 Auto Scaling resource (for example, an Auto Scaling group,
 *             instance, or load balancer).</p>
 *
 * @throws {@link AutoScalingServiceException}
 * <p>Base exception class for all service exceptions from AutoScaling service.</p>
 *
 * @public
 * @example To describe termination policy types
 * ```javascript
 * // This example describes the available termination policy types.
 * const input = {};
 * const command = new DescribeTerminationPolicyTypesCommand(input);
 * const response = await client.send(command);
 * /* response ==
 * {
 *   "TerminationPolicyTypes": [
 *     "ClosestToNextInstanceHour",
 *     "Default",
 *     "NewestInstance",
 *     "OldestInstance",
 *     "OldestLaunchConfiguration"
 *   ]
 * }
 * *\/
 * // example id: autoscaling-describe-termination-policy-types-1
 * ```
 *
 */
export declare class DescribeTerminationPolicyTypesCommand extends DescribeTerminationPolicyTypesCommand_base {
}
