import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { AutoScalingClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../AutoScalingClient";
import { EnableMetricsCollectionQuery } from "../models/models_0";
/**
 * @public
 */
export { __MetadataBearer, $Command };
/**
 * @public
 *
 * The input for {@link EnableMetricsCollectionCommand}.
 */
export interface EnableMetricsCollectionCommandInput extends EnableMetricsCollectionQuery {
}
/**
 * @public
 *
 * The output of {@link EnableMetricsCollectionCommand}.
 */
export interface EnableMetricsCollectionCommandOutput extends __MetadataBearer {
}
declare const EnableMetricsCollectionCommand_base: {
    new (input: EnableMetricsCollectionCommandInput): import("@smithy/smithy-client").CommandImpl<EnableMetricsCollectionCommandInput, EnableMetricsCollectionCommandOutput, AutoScalingClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: EnableMetricsCollectionCommandInput): import("@smithy/smithy-client").CommandImpl<EnableMetricsCollectionCommandInput, EnableMetricsCollectionCommandOutput, AutoScalingClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Enables group metrics collection for the specified Auto Scaling group.</p>
 *          <p>You can use these metrics to track changes in an Auto Scaling group and to set alarms on
 *             threshold values. You can view group metrics using the Amazon EC2 Auto Scaling console or the CloudWatch
 *             console. For more information, see <a href="https://docs.aws.amazon.com/autoscaling/ec2/userguide/ec2-auto-scaling-cloudwatch-monitoring.html">Monitor
 *                 CloudWatch metrics for your Auto Scaling groups and instances</a> in the
 *                 <i>Amazon EC2 Auto Scaling User Guide</i>.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { AutoScalingClient, EnableMetricsCollectionCommand } from "@aws-sdk/client-auto-scaling"; // ES Modules import
 * // const { AutoScalingClient, EnableMetricsCollectionCommand } = require("@aws-sdk/client-auto-scaling"); // CommonJS import
 * const client = new AutoScalingClient(config);
 * const input = { // EnableMetricsCollectionQuery
 *   AutoScalingGroupName: "STRING_VALUE", // required
 *   Metrics: [ // Metrics
 *     "STRING_VALUE",
 *   ],
 *   Granularity: "STRING_VALUE", // required
 * };
 * const command = new EnableMetricsCollectionCommand(input);
 * const response = await client.send(command);
 * // {};
 *
 * ```
 *
 * @param EnableMetricsCollectionCommandInput - {@link EnableMetricsCollectionCommandInput}
 * @returns {@link EnableMetricsCollectionCommandOutput}
 * @see {@link EnableMetricsCollectionCommandInput} for command's `input` shape.
 * @see {@link EnableMetricsCollectionCommandOutput} for command's `response` shape.
 * @see {@link AutoScalingClientResolvedConfig | config} for AutoScalingClient's `config` shape.
 *
 * @throws {@link ResourceContentionFault} (server fault)
 *  <p>You already have a pending update to an Amazon EC2 Auto Scaling resource (for example, an Auto Scaling group,
 *             instance, or load balancer).</p>
 *
 * @throws {@link AutoScalingServiceException}
 * <p>Base exception class for all service exceptions from AutoScaling service.</p>
 *
 * @public
 * @example To enable metrics collection for an Auto Scaling group
 * ```javascript
 * // This example enables data collection for the specified Auto Scaling group.
 * const input = {
 *   "AutoScalingGroupName": "my-auto-scaling-group",
 *   "Granularity": "1Minute"
 * };
 * const command = new EnableMetricsCollectionCommand(input);
 * await client.send(command);
 * // example id: autoscaling-enable-metrics-collection-1
 * ```
 *
 */
export declare class EnableMetricsCollectionCommand extends EnableMetricsCollectionCommand_base {
}
