import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { AutoScalingClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../AutoScalingClient";
import { PutNotificationConfigurationType } from "../models/models_0";
/**
 * @public
 */
export { __MetadataBearer, $Command };
/**
 * @public
 *
 * The input for {@link PutNotificationConfigurationCommand}.
 */
export interface PutNotificationConfigurationCommandInput extends PutNotificationConfigurationType {
}
/**
 * @public
 *
 * The output of {@link PutNotificationConfigurationCommand}.
 */
export interface PutNotificationConfigurationCommandOutput extends __MetadataBearer {
}
declare const PutNotificationConfigurationCommand_base: {
    new (input: PutNotificationConfigurationCommandInput): import("@smithy/smithy-client").CommandImpl<PutNotificationConfigurationCommandInput, PutNotificationConfigurationCommandOutput, AutoScalingClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: PutNotificationConfigurationCommandInput): import("@smithy/smithy-client").CommandImpl<PutNotificationConfigurationCommandInput, PutNotificationConfigurationCommandOutput, AutoScalingClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Configures an Auto Scaling group to send notifications when specified events take place.
 *             Subscribers to the specified topic can have messages delivered to an endpoint such as a
 *             web server or an email address.</p>
 *          <p>This configuration overwrites any existing configuration.</p>
 *          <p>For more information, see <a href="https://docs.aws.amazon.com/autoscaling/ec2/userguide/ASGettingNotifications.html">Getting Amazon SNS
 *                 notifications when your Auto Scaling group scales</a> in the
 *                 <i>Amazon EC2 Auto Scaling User Guide</i>.</p>
 *          <p>If you exceed your maximum limit of SNS topics, which is 10 per Auto Scaling group, the call
 *             fails.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { AutoScalingClient, PutNotificationConfigurationCommand } from "@aws-sdk/client-auto-scaling"; // ES Modules import
 * // const { AutoScalingClient, PutNotificationConfigurationCommand } = require("@aws-sdk/client-auto-scaling"); // CommonJS import
 * const client = new AutoScalingClient(config);
 * const input = { // PutNotificationConfigurationType
 *   AutoScalingGroupName: "STRING_VALUE", // required
 *   TopicARN: "STRING_VALUE", // required
 *   NotificationTypes: [ // AutoScalingNotificationTypes // required
 *     "STRING_VALUE",
 *   ],
 * };
 * const command = new PutNotificationConfigurationCommand(input);
 * const response = await client.send(command);
 * // {};
 *
 * ```
 *
 * @param PutNotificationConfigurationCommandInput - {@link PutNotificationConfigurationCommandInput}
 * @returns {@link PutNotificationConfigurationCommandOutput}
 * @see {@link PutNotificationConfigurationCommandInput} for command's `input` shape.
 * @see {@link PutNotificationConfigurationCommandOutput} for command's `response` shape.
 * @see {@link AutoScalingClientResolvedConfig | config} for AutoScalingClient's `config` shape.
 *
 * @throws {@link LimitExceededFault} (client fault)
 *  <p>You have already reached a limit for your Amazon EC2 Auto Scaling
 *             resources (for example, Auto Scaling groups, launch configurations, or lifecycle hooks). For
 *             more information, see <a href="https://docs.aws.amazon.com/autoscaling/ec2/APIReference/API_DescribeAccountLimits.html">DescribeAccountLimits</a> in the <i>Amazon EC2 Auto Scaling API
 *             Reference</i>.</p>
 *
 * @throws {@link ResourceContentionFault} (server fault)
 *  <p>You already have a pending update to an Amazon EC2 Auto Scaling resource (for example, an Auto Scaling group,
 *             instance, or load balancer).</p>
 *
 * @throws {@link ServiceLinkedRoleFailure} (server fault)
 *  <p>The service-linked role is not yet ready for use.</p>
 *
 * @throws {@link AutoScalingServiceException}
 * <p>Base exception class for all service exceptions from AutoScaling service.</p>
 *
 * @public
 * @example To add an Auto Scaling notification
 * ```javascript
 * // This example adds the specified notification to the specified Auto Scaling group.
 * const input = {
 *   "AutoScalingGroupName": "my-auto-scaling-group",
 *   "NotificationTypes": [
 *     "autoscaling:TEST_NOTIFICATION"
 *   ],
 *   "TopicARN": "arn:aws:sns:us-west-2:123456789012:my-sns-topic"
 * };
 * const command = new PutNotificationConfigurationCommand(input);
 * await client.send(command);
 * // example id: autoscaling-put-notification-configuration-1
 * ```
 *
 */
export declare class PutNotificationConfigurationCommand extends PutNotificationConfigurationCommand_base {
}
